AuthRepositoryImpl class

Implemented types

Constructors

AuthRepositoryImpl({required String baseUrl})

Properties

baseUrl String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAuthHeaders() Future<Map<String, String>>
override
getCurrentUser() Future<Map<String, dynamic>?>
override
getToken() Future<String?>
override
login(String email, String password) Future<String?>
override
logout() Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(String email, String password) Future<String?>
override
toString() String
A string representation of this object.
inherited
updateCurrentUser(Map<String, dynamic> updates) Future<Map<String, dynamic>?>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited